%global srcname msrest
%global common_description %{summary}.

%global _with_python2 0%{?rhel} || 0%{?fedora} <= 29
%global py2_prefix %{?rhel:python}%{?fedora:python2}
# Some Python 3 libraries required by msrest are not available in EL
%global _with_python3 0%{?fedora}
# Tests require a more recent version of requests library than the one available
# in EL
%global _with_tests 0%{?fedora}
# EL is missing recommonmark library to build documentation
%global _with_doc 0%{?fedora}
%global pydoc_prefix %{?rhel:python}%{?fedora:python%{python3_pkgversion}}
%global sphinxbuild sphinx-build%{?fedora:-%{python3_version}}

# Ignore bytecode compilation errors with Python 2 (since the library provides
# some Python 3-only files)
%global _python_bytecompile_errors_terminate_build 0%{!?_with_python2}


Name:           python-%{srcname}
Version:        0.6.10
Release:        1%{?dist}
Summary:        The runtime library "msrest" for AutoRest generated Python clients

License:        MIT
URL:            https://github.com/Azure/msrest-for-python
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz
# Fix build with old versions of setuptools library
Patch0:         %{name}-0.6.1-setup.patch
# Fix support with isodate < 0.6.0
Patch1:         %{name}-0.6.10-isodate.patch
# Disable tests requiring an Internet connection
Patch2:         %{name}-0.6.1-tests.patch

%if 0%{?_with_python2}
BuildRequires:  %{py2_prefix}-devel
BuildRequires:  %{py2_prefix}-setuptools
%if 0%{?_with_tests}
BuildRequires:  %{py2_prefix}-certifi
BuildRequires:  %{py2_prefix}-enum34
BuildRequires:  %{py2_prefix}-futures
BuildRequires:  %{py2_prefix}-httpretty
BuildRequires:  %{py2_prefix}-isodate
BuildRequires:  %{py2_prefix}-mock
BuildRequires:  %{py2_prefix}-requests
BuildRequires:  %{py2_prefix}-requests-oauthlib
BuildRequires:  %{py2_prefix}-setuptools
BuildRequires:  %{py2_prefix}-typing
BuildRequires:  %{?!rhel:%{py2_prefix}-}pytest
%endif
%endif
%if 0%{?_with_python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
%if 0%{?_with_tests}
BuildRequires:  python%{python3_pkgversion}-aiodns
BuildRequires:  python%{python3_pkgversion}-aiohttp
BuildRequires:  python%{python3_pkgversion}-certifi
BuildRequires:  python%{python3_pkgversion}-httpretty
BuildRequires:  python%{python3_pkgversion}-isodate
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-pytest-asyncio
BuildRequires:  python%{python3_pkgversion}-requests
BuildRequires:  python%{python3_pkgversion}-requests-oauthlib
BuildRequires:  python%{python3_pkgversion}-trio
%endif
%endif
%if 0%{?_with_doc}
BuildRequires:  %{pydoc_prefix}-pip
BuildRequires:  %{pydoc_prefix}-recommonmark
BuildRequires:  %{pydoc_prefix}-sphinx
BuildRequires:  %{pydoc_prefix}-sphinx_rtd_theme
%endif
BuildArch:      noarch

%description
%{common_description}


%if 0%{?_with_python2}
%package -n python2-%{srcname}
Summary:        %{summary}
Requires:       %{py2_prefix}-certifi
Requires:       %{py2_prefix}-enum34
Requires:       %{py2_prefix}-requests
Requires:       %{py2_prefix}-requests-oauthlib
Requires:       %{py2_prefix}-typing
%if 0%{?fedora} <= 27
Requires:       python-isodate
%else
Requires:       %{py2_prefix}-isodate
%endif
%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_description}
%endif


%if 0%{?_with_python3}
%package -n python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}
Requires:       python%{python3_pkgversion}-aiodns
Requires:       python%{python3_pkgversion}-aiohttp
Requires:       python%{python3_pkgversion}-certifi
Requires:       python%{python3_pkgversion}-isodate
Requires:       python%{python3_pkgversion}-requests
Requires:       python%{python3_pkgversion}-requests-oauthlib
Requires:       python%{python3_pkgversion}-trio
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

%description -n python%{python3_pkgversion}-%{srcname}
%{common_description}
%endif


%if 0%{?_with_doc}
%package doc
Summary:        Documentation for %{name}

%description doc
This package provides documentation for %{name}.
%endif


%prep
%autosetup -p1 -n %{srcname}-for-python-%{version}


%build
%if 0%{?_with_python2}
%py2_build
%endif
%if 0%{?_with_python3}
%py3_build
%endif

%if 0%{?_with_doc}
pushd doc/
%{sphinxbuild} -b html -d _build/doctrees/ . _build/html/
rm _build/html/.buildinfo
popd
%endif


%install
%if 0%{?_with_python2}
%py2_install
%endif
%if 0%{?_with_python3}
%py3_install
%endif


%check
%if 0%{_with_tests}
%if 0%{?_with_python2}
py.test-%{python2_version}
%endif
%if 0%{?_with_python3}
py.test-%{python3_version}
%endif
%endif


%if 0%{?_with_python2}
%files -n python2-%{srcname}
%doc README.rst
%license LICENSE.md
%{python2_sitelib}/%{srcname}/
%{python2_sitelib}/%{srcname}-*.egg-info/
%endif


%if 0%{?_with_python3}
%files -n python%{python3_pkgversion}-%{srcname}
%doc README.rst
%license LICENSE.md
%{python3_sitelib}/%{srcname}/
%{python3_sitelib}/%{srcname}-*.egg-info/
%endif


%if 0%{?_with_doc}
%files doc
%doc doc/_build/html/
%license LICENSE.md
%endif


%changelog
* Fri Sep 06 2019 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.10-1
- Update to 0.6.10
- Spec cleanup
- Fix tests

* Fri Aug 09 2019 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.9-1
- Update to 0.6.9

* Mon Apr 08 2019 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.6-1
- Update to 0.6.6

* Mon Feb 04 2019 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.4-1
- Update to 0.6.4

* Wed Nov 21 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.2-1
- Update to 0.6.2

* Tue Nov 13 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.1-6
- Fix typo in Requires for python-isodate

* Sun Nov 11 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.1-5
- Fix Requires for Fedora <= 27

* Sun Nov 11 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.1-4
- Fix comments

* Sat Nov 10 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.1-3
- Build documentation
- Fix BuildRequires for Fedora <= 27

* Sat Nov 10 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.1-2
- Enable dependency on python3-trio for Fedora >= 29 only

* Sat Nov 10 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.6.1-1
- Update to 0.6.1
